Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(576)

Unified Diff: Source/core/html/HTMLPlugInElement.cpp

Issue 1115353002: Update renderer to layoutObject in core/html. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/html/HTMLPlugInElement.h ('k') | Source/core/html/HTMLProgressElement.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/html/HTMLPlugInElement.cpp
diff --git a/Source/core/html/HTMLPlugInElement.cpp b/Source/core/html/HTMLPlugInElement.cpp
index f300c0155d73d06fb99e611b377685381f0f4f07..a160e99f701b772801d3bc459fb1a77c5a9d925a 100644
--- a/Source/core/html/HTMLPlugInElement.cpp
+++ b/Source/core/html/HTMLPlugInElement.cpp
@@ -147,8 +147,8 @@ bool HTMLPlugInElement::willRespondToMouseClickEvents()
void HTMLPlugInElement::removeAllEventListeners()
{
HTMLFrameOwnerElement::removeAllEventListeners();
- if (LayoutPart* renderer = existingLayoutPart()) {
- if (Widget* widget = renderer->widget())
+ if (LayoutPart* layoutObject = existingLayoutPart()) {
+ if (Widget* widget = layoutObject->widget())
widget->eventListenersRemoved();
}
}
@@ -192,7 +192,7 @@ void HTMLPlugInElement::updateWidget()
}
}
-void HTMLPlugInElement::requestPluginCreationWithoutRendererIfPossible()
+void HTMLPlugInElement::requestPluginCreationWithoutLayoutObjectIfPossible()
{
if (m_serviceType.isEmpty())
return;
@@ -204,10 +204,10 @@ void HTMLPlugInElement::requestPluginCreationWithoutRendererIfPossible()
if (layoutObject() && layoutObject()->isLayoutPart())
return;
- createPluginWithoutRenderer();
+ createPluginWithoutLayoutObject();
}
-void HTMLPlugInElement::createPluginWithoutRenderer()
+void HTMLPlugInElement::createPluginWithoutLayoutObject()
{
ASSERT(document().frame()->loader().client()->canCreatePluginWithoutRenderer(m_serviceType));
@@ -265,7 +265,7 @@ void HTMLPlugInElement::detach(const AttachContext& context)
LayoutObject* HTMLPlugInElement::createLayoutObject(const ComputedStyle& style)
{
// Fallback content breaks the DOM->Renderer class relationship of this
// class and all superclasses because createObject won't necessarily return
// a LayoutEmbeddedObject or LayoutPart.
if (useFallbackContent())
@@ -464,7 +464,7 @@ bool HTMLPlugInElement::isImageType()
LayoutEmbeddedObject* HTMLPlugInElement::layoutEmbeddedObject() const
{
- // HTMLObjectElement and HTMLEmbedElement may return arbitrary renderers
+ // HTMLObjectElement and HTMLEmbedElement may return arbitrary layoutObjects
// when using fallback content.
if (!layoutObject() || !layoutObject()->isEmbeddedObject())
return nullptr;
@@ -516,16 +516,16 @@ bool HTMLPlugInElement::requestObject(const String& url, const String& mimeType,
return loadOrRedirectSubframe(completedURL, getNameAttribute(), true);
}
-bool HTMLPlugInElement::loadPlugin(const KURL& url, const String& mimeType, const Vector<String>& paramNames, const Vector<String>& paramValues, bool useFallback, bool requireRenderer)
+bool HTMLPlugInElement::loadPlugin(const KURL& url, const String& mimeType, const Vector<String>& paramNames, const Vector<String>& paramValues, bool useFallback, bool requireLayoutObject)
{
LocalFrame* frame = document().frame();
if (!frame->loader().allowPlugins(AboutToInstantiatePlugin))
return false;
- LayoutEmbeddedObject* renderer = layoutEmbeddedObject();
- // FIXME: This code should not depend on renderer!
- if ((!renderer && requireRenderer) || useFallback)
+ LayoutEmbeddedObject* layoutObject = layoutEmbeddedObject();
+ // FIXME: This code should not depend on layoutObject!
+ if ((!layoutObject && requireLayoutObject) || useFallback)
return false;
WTF_LOG(Plugins, "%p Plugin URL: %s", this, m_url.utf8().data());
@@ -538,14 +538,14 @@ bool HTMLPlugInElement::loadPlugin(const KURL& url, const String& mimeType, cons
bool loadManually = document().isPluginDocument() && !document().containsPlugins();
placeholder = frame->loader().client()->createPluginPlaceholder(document(), url, paramNames, paramValues, mimeType, loadManually);
if (!placeholder) {
- FrameLoaderClient::DetachedPluginPolicy policy = requireRenderer ? FrameLoaderClient::FailOnDetachedPlugin : FrameLoaderClient::AllowDetachedPlugin;
+ FrameLoaderClient::DetachedPluginPolicy policy = requireLayoutObject ? FrameLoaderClient::FailOnDetachedPlugin : FrameLoaderClient::AllowDetachedPlugin;
widget = frame->loader().client()->createPlugin(this, url, paramNames, paramValues, mimeType, loadManually, policy);
}
}
if (!placeholder && !widget) {
- if (renderer && !renderer->showsUnavailablePluginIndicator())
- renderer->setPluginUnavailabilityReason(LayoutEmbeddedObject::PluginMissing);
+ if (layoutObject && !layoutObject->showsUnavailablePluginIndicator())
+ layoutObject->setPluginUnavailabilityReason(LayoutEmbeddedObject::PluginMissing);
setPlaceholder(nullptr);
return false;
}
@@ -555,7 +555,7 @@ bool HTMLPlugInElement::loadPlugin(const KURL& url, const String& mimeType, cons
return true;
}
- if (renderer) {
+ if (layoutObject) {
setWidget(widget);
setPersistedPluginWidget(nullptr);
} else {
@@ -265,7 +265,7 @@ void HTMLPlugInElement::detach(const AttachContext& context)
LayoutObject* HTMLPlugInElement::createLayoutObject(const ComputedStyle& style)
{
- // Fallback content breaks the DOM->Renderer class relationship of this
+ // Fallback content breaks the DOM->layoutObject class relationship of this
// class and all superclasses because createObject won't necessarily return
// a LayoutEmbeddedObject or LayoutPart.
« no previous file with comments | « Source/core/html/HTMLPlugInElement.h ('k') | Source/core/html/HTMLProgressElement.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698